import { select } from 'd3';
import { viz } from './viz';
import { data } from '@curran/penguins';
import { observeResize } from '@curran/responsive-axes';

export const main = (container, { state, setState }) => {
  const dimensions = observeResize({
    state,
    setState,
    container,
  });

  if (dimensions === null) return;

  const { width, height } = dimensions;

  const svg = select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height);

  const xValue = (d) => d.bill_length_mm;
  const yValue = (d) => d.flipper_length_mm;

  const filteredData = data.filter(
    (d) => !(isNaN(xValue(d)) || isNaN(yValue(d))),
  );

  viz(svg, {
    data: filteredData,
    xValue,
    xAxisLabelText: 'Bill Length (mm)',
    xAxisLabelOffset: 38,
    yValue,
    yAxisLabelText: 'Flipper Length (mm)',
    yAxisLabelOffset: 17,
    innerRectFill: '#E8E8E8',
    circleRadius: 153 / 20,
    circleOpacity: 629 / 1000,
    marginTop: 20,
    marginBottom: 50,
    marginLeft: 54,
    marginRight: 20,
    width,
    height,
  });

  // Sample row (d):
  // {
  //   "species": "Adelie",
  //   "island": "Torgersen",
  //   "bill_length_mm": 39.1,
  //   "bill_depth_mm": 18.7,
  //   "flipper_length_mm": 181,
  //   "body_mass_g": 3750,
  //   "sex": "male",
  //   "year": "2007"
  // }
};
